# from pkglts.templating import same
#
# try:
#     from .github_versioning import fetch_github_version
# except ImportError:
#     fetch_github_version = same
#
#
# mapping = {'version.fetch_github': fetch_github_version}
