# import github3


# def fetch_github_version(txt, env):
#     if txt == 'off':
#         return ""
#
#     # fetch version
#
#     # store it in env
#     cfg = env['version']
#     cfg['major'] = "0"
#     cfg['minor'] = "9"
#     cfg['post'] = "1"
#
#     # return no txt
#     return ""
